@@ -420,7 +420,12 @@ class VacBot():
         response = event['body']['data']
         
         try:
-            mapid = response['info'][0]['mid']
+            for mapstatus in response['info']:
+                if mapstatus['using'] == 1:
+                    mapid = mapstatus['mid']
+                    
+                    _LOGGER.debug("Using Map: " + str(mapid))
+
             self.__map.rooms = []
             self.exc_command('getMapSet', {'mid': mapid,'type': 'ar'})
         except:
